@@ -100,7 +100,11 @@ def wrap_callback_handler(handler):
             self.handler = handler
         
         def handle(self, added, removed):
-            self.handler.callback(triplify(added), triplify(removed))
+            try:
+                self.handler.callback(triplify(added), triplify(removed))
+            except Exception, e:
+                # Don't let the exception propagate to python-kp since that might break things
+                print('CallbackHandlerWrapper.handle: Caught exception %s' % e)
 
     if isinstance(handler, types.FunctionType):
         # Wrap the function inside a delegating class
